#!/bin/sh

export OCF_ROOT=/usr/lib/ocf
export OCF_RESOURCE_INSTANCE=test_res

export OCF_RESKEY_pgpoolconf="/usr/local/etc/pgpool.conf"
export OCF_RESKEY_pcpconf="/usr/local/etc/pcp.conf"
export OCF_RESKEY_hbaconf="/usr/local/etc/pool_hba.conf"
export OCF_RESKEY_logfile=""
export OCF_RESKEY_options="-D"
export OCF_RESKEY_pgpooluser="postgres"
# export OCF_RESKEY_checkmethod="pid"
# export OCF_RESKEY_checkstring=""
# export OCF_RESKEY_checkmethod="pcp"
# export OCF_RESKEY_checkstring="10 localhost 9898 postgres pass"
export OCF_RESKEY_checkmethod="psql"
export OCF_RESKEY_checkstring="-h localhost -U postgres -p 5432 -c \\'SELECT 1\\'"

sh pgpool $*

